@@ -9,8 +9,8 @@ def import_path(path):
         return import_module(path)
     except ImportError:
         return _import_module_entry(path)
-    except Exception as e:
-        raise ImportError(path) from e
+    except BaseException:
+        raise ImportError(path)
 
 
 def _import_module_entry(path):
@@ -18,8 +18,8 @@ def _import_module_entry(path):
     try:
         module = import_module(module)
         return module.__dict__[name]
-    except Exception as e:
-        raise ImportError(path) from e
+    except BaseException:
+        raise ImportError(path)
 
 
 def _split_by_last_dot(expr):
